(*
    Id3Tag - Rename dialog
    Copyright (c) 1998-2002,2003 Alessandro Scotti
    http://www.ascotti.org/

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*)
unit Rename;

interface

uses
  Id3,
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ComCtrls, ExtCtrls;

type
  TformRename = class(TForm)
    grpOptions: TRadioGroup;
    optArtistTitle: TRadioButton;
    optTitle: TRadioButton;
    optArtistTitleRound: TRadioButton;
    lstFiles: TListView;
    lblPreview: TLabel;
    btnOk: TButton;
    btnCancel: TButton;
    optCustom: TRadioButton;
    edtFormat: TEdit;
    GroupBox1: TGroupBox;
    chkReplaceSpace: TCheckBox;
    chkAllowEmptyFields: TCheckBox;
    chkCheckLength: TCheckBox;
    procedure optTitleClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure edtFormatChange(Sender: TObject);
    procedure FormCreate(Sender: TObject);
  private
    { Private declarations }
    procedure Changed;
  public
    function GetNameFromId3( const Fmt: string; Info: TId3Info ): string;
    function GetNameFormat: string;
    { Public declarations }
  end;

var
  formRename: TformRename;

implementation

uses Tools;

{$R *.DFM}

function TformRename.GetNameFromId3( const Fmt: string; Info: TId3Info ): string;
var
  I: integer;
  V: boolean;
begin
  Result := Fmt;

  V := ReplaceId3Tokens( Result, Info );
  
  if( not V )and( not chkAllowEmptyFields.Checked ) then begin
    (* Some substitution was not valid, so clear the string *)
    Result := ' *** Name containes empty field(s)';
  end
  else begin
    if( chkReplaceSpace.Checked ) then begin
      for I:=1 to Length(Result) do
        if( Result[I] = ' ' ) then Result[I] := '_';
    end;
    (* Replace characters that are illegal in a filename *)
    for I:=1 to Length(Result) do
      if( StrScan( '/\:|<>?*', Result[I] ) <> nil ) then
        Result[I] := '_';
  end;

  if( chkCheckLength.Checked )and( Length(Result) > 64 ) then begin
    Result := ' *** Name exceeds 64 characters';
  end;
end;

function TformRename.GetNameFormat: string;
begin
  Result := edtFormat.Text;
end;

procedure TformRename.optTitleClick(Sender: TObject);
begin
  if( optCustom.Checked ) then begin
    edtFormat.Enabled := true;
    edtFormat.Text := optCustom.Hint;
    edtFormat.SetFocus;
  end
  else begin
    edtFormat.Enabled := false;
    if( optTitle.Checked ) then edtFormat.Text := optTitle.Hint;
    if( optArtistTitle.Checked ) then edtFormat.Text := optArtistTitle.Hint;
    if( optArtistTitleRound.Checked ) then edtFormat.Text := optArtistTitleRound.Hint;
  end;
  Changed;
end;

procedure TformRename.Changed;
var
  I: integer;
  N: TListItem;
begin
  lstFiles.Items.BeginUpdate;
  for I:=0 to lstFiles.Items.Count-1 do begin
    N := lstFiles.Items[I];
    if( N.Subitems.Count <= 0 ) then begin
      N.Subitems.Add( GetNameFromId3( edtFormat.Text, TId3Info(N.Data) ) )
    end
    else begin
      N.Subitems[0] := GetNameFromId3( edtFormat.Text, TId3Info(N.Data) );
    end
  end;
  lstFiles.Items.EndUpdate;
end;

procedure TformRename.FormShow(Sender: TObject);
begin
  Changed;
end;

procedure TformRename.edtFormatChange(Sender: TObject);
begin
  if( optCustom.Checked ) then begin
    optCustom.Hint := edtFormat.Text;
    optTitleClick( Self );
  end;
end;

procedure TformRename.FormCreate(Sender: TObject);
begin
  optTitleClick( Self );
end;

end.
